==> gsignal_0.3-6.tar.gz: gsignal/README.md <==

# gsignal <img src=man/figures/gsignal_logo.png align="right" height="139" />

<!-- badges: start -->

[![Project Status: Active – The project has reached a stable, usable
state and is being actively
developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/gsignal)](https://cran.r-project.org/package=gsignal)
[![R-CMD-check](https://github.com/gjmvanboxtel/gsignal/workflows/R-CMD-check/badge.svg)](https://github.com/gjmvanboxtel/gsignal/actions)
[![](https://cranlogs.r-pkg.org/badges/gsignal)](https://CRAN.R-project.org/package=gsignal)
[![codecov](https://app.codecov.io/gh/gjmvanboxtel/gsignal/branch/master/graph/badge.svg?token=7ZAU9VV73X)](https://app.codecov.io/gh/gjmvanboxtel/gsignal)
[![license](https://img.shields.io/badge/license-GPL--3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)
[![Codecov test
coverage](https://app.codecov.io/gh/gjmvanboxtel/gsignal/branch/master/graph/badge.svg)](https://app.codecov.io/gh/gjmvanboxtel/gsignal?branch=master)
[![R-CMD-check](https://github.com/gjmvanboxtel/gsignal/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/gjmvanboxtel/gsignal/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

R implementation of the ‘Octave’ package ‘signal’.

## Installation

To install the stable version from CRAN:

    install.packages("gsignal")

The latest development version can be downloaded directly from
[GitHub](https://github.com/gjmvanboxtel/gsignal):

    library(devtools)
    install_github("gjmvanboxtel/gsignal")

An overview of the functions in the package is available in the
[vignette](https://CRAN.R-project.org/package=gsignal).

==> gsignal_0.3-7.tar.gz: gsignal/README.md <==

# gsignal <img src=man/figures/gsignal_logo.png align="right" height="139" />

<!-- badges: start -->

[![Project Status: Active – The project has reached a stable, usable
state and is being actively
developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/gsignal)](https://cran.r-project.org/package=gsignal)
[![R-CMD-check](https://github.com/gjmvanboxtel/gsignal/workflows/R-CMD-check/badge.svg)](https://github.com/gjmvanboxtel/gsignal/actions)
[![](https://cranlogs.r-pkg.org/badges/gsignal)](https://CRAN.R-project.org/package=gsignal)
[![license](https://img.shields.io/badge/license-GPL--3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)
[![codecov](https://codecov.io/github/gjmvanboxtel/gsignal/graph/badge.svg?token=7ZAU9VV73X)](https://app.codecov.io/github/gjmvanboxtel/gsignal)
[![R-CMD-check](https://github.com/gjmvanboxtel/gsignal/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/gjmvanboxtel/gsignal/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

R implementation of the ‘Octave’ package ‘signal’.

## Installation

To install the stable version from CRAN:

    install.packages("gsignal")

The latest development version can be downloaded directly from
[GitHub](https://github.com/gjmvanboxtel/gsignal):

    library(devtools)
    install_github("gjmvanboxtel/gsignal")

An overview of the functions in the package is available in the
[vignette](https://CRAN.R-project.org/package=gsignal).
